/*
    Change a little bit the superfish menu for PyLucid.
    superfish menu homepage:
        http://users.tpg.com.au/j_birch/plugins/superfish/
*/
.sf-menu {
    /* border: 2px solid #ff0000; */
    
    min-width: 54em; /* no linebreak in admin index */ 
    width: 90%;
    height: 3em;
    clear: both;
    float: none;
    
    /* from django admin panel: */
    font-size:11px;
    line-height:14px;
    font-family:"Lucida Grande","DejaVu Sans","Bitstream Vera Sans",Verdana,Arial,sans-serif;
}

/* grow wider all items */ 
.sf-menu ul {
    width:          16em; /* left offset of submenus need to match (see below) */
}
ul.sf-menu li li:hover ul,
ul.sf-menu li li.sfHover ul,
ul.sf-menu li li li:hover ul,
ul.sf-menu li li li.sfHover ul {
    left:           16em; /* match ul width */
}


