.pylucid_form * {
    /* reset django values */
    font-size: 1em;
}
.pylucid_form {
    font-size: 1.1em;
}
.pylucid_form h2 {
    margin: 0.5em;
    font-size: 1.5em;
}
.pylucid_form h2:hover {
    background-color: #eee;
}
.pylucid_form fieldset {
    margin: 1em;
    padding: 0.5em;
}
.pylucid_form div.field {
    margin: 0.5em 0em 0.5em 0em;
    padding: 0.5em 0em 0.5em 0em;
}
.pylucid_form div.error {
    padding: 0.5em;
    border:1px solid #f00;
    background-color: #ffeeee;
}
.pylucid_form .errorlist a {
    color: #ffffff;
}
.pylucid_form .errorlist a:hover {
    color: #ffff00;
}
.pylucid_form label {
    width: 150px;
    float: left;
}
.pylucid_form .field_help_text {
    margin-left: 150px;
    font-size: 0.75em;
}
.pylucid_form input, .pylucid_form textarea {
    width: 100%;
    max-width: 80%;
}
.pylucid_form .helper_buttons input, .pylucid_form input[type=checkbox] {
    width: auto;
}

/* hover highlight all fields */
.pylucid_form .field {
    border:1px solid #ffffff;
    background-color: #ffffff;
}
.pylucid_form .field:hover {
    border-color: #dddddd;
    background-color: #fafafa;
}
.pylucid_form .field input, .pylucid_form .field select, .pylucid_form .field textarea {
    border:1px solid #cccccc;
}
.pylucid_form .field:hover input, .pylucid_form .field:hover select, .pylucid_form .field:hover textarea {
    border-color: #000000;
}
/* submit, reset, etc. buttons */
.pylucid_form .helper_buttons {
    background-color: #def;
    padding: 10px;
}
.pylucid_form .helper_buttons input, .pylucid_form .helper_buttons button {
    min-width: 4em;
    padding: 0.3em;
    margin: 0.3em;
    background: #fff;
    border-color: #DDD #AAA #AAA #DDD;
    border-style: solid;
    border-width: 1px;
    color: #000;
}

#page_msg pre {
  color: #ffffff;
  border: 1px solid #eeeeee;
  padding: 5px;
  margin: 5px;
}

table.info {
    margin: 0.4em;
}
table.info td {
    padding: 0.5em;
}
table.info caption {
    font-weight:bold
}
/* ----------------------------------------------------------------------------
   Headline Anchor
------------------------------------------------------------------------------- */
.top_link {
  color: #000000;
}
.uarr {
  color: #eeeeee;
}
.top_link:hover .uarr {
  color: #000000;
}
.section_anchor {
  text-shadow: 0px 0px #ffffff;
  text-decoration:none;
  color: #eeeeee!important;
  padding-right: 1em;
}
.headline_anchor:hover .section_anchor {
  color: #999999;
}
.section_anchor:hover {
  color:#000000!important;
  text-decoration:underline;
  text-shadow: 2px 2px 2px #999999;
}
/* ----------------------------------------------------------------------------
   TOC Plugin
------------------------------------------------------------------------------- */
.PyLucidPlugins.TOC {
  border: 1px solid #eeeeee;
  background-color: #fefefe;
  margin: 3em;
  padding: 1em 0em 1em 0em;
}
.PyLucidPlugins.TOC h3 {
  margin: 0em;
  color: #333333;
}
.PyLucidPlugins.TOC * {
  margin: 0em;
  color: #dddddd;
}
.PyLucidPlugins.TOC a {
  color: #777777;
}
.PyLucidPlugins.TOC a:hover {
  color: #286ea0;
}
/* ----------------------------------------------------------------------------
   jquery.textarearesizer.js
   http://plugins.jquery.com/project/TextAreaResizer
------------------------------------------------------------------------------- */
div.grippie {
    background-color: #eeeeee;
    cursor:s-resize;
    height:9px;
    width:100%;
    overflow:hidden;
}
div.grippie:hover {
    background-color: #cccccc;
}
textarea {
    display:block;
    margin-bottom:0pt;
    min-height: 8em;
	width: 85% !important;
}
/* ----------------------------------------------------------------------------
   CodeMirror
   http://marijn.haverbeke.nl/codemirror/css/
------------------------------------------------------------------------------- */
.CodeMirror-wrapping {
  overflow: auto;
  height: 100%;
  width: 90%;
  border: 1px solid #bbb;
}
