wget --timestamp http://github.com/joshuaclayton/blueprint-css/raw/master/blueprint/screen.css
wget --timestamp http://github.com/joshuaclayton/blueprint-css/raw/master/blueprint/print.css
wget --timestamp http://github.com/joshuaclayton/blueprint-css/raw/master/blueprint/ie.css